@@ -1,18 +1,16 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef GRANTLEE_THEME_P_H
-#define GRANTLEE_THEME_P_H
+#pragma once
 
 #include "grantleeki18nlocalizer.h"
 #include "grantleetheme.h"
-
-#include <grantlee/engine.h>
-#include <grantlee/template.h>
-#include <grantlee/templateloader.h>
+#include <KTextTemplate/Engine>
+#include <KTextTemplate/Template>
+#include <KTextTemplate/TemplateLoader>
 
 namespace GrantleeTheme
 {
@@ -25,8 +23,8 @@ public:
 
     static void setupEngine();
     void setupLoader();
-    Q_REQUIRED_RESULT Grantlee::Context createContext(const QVariantHash &data = QVariantHash(), const QByteArray &applicationDomain = QByteArray());
-    Q_REQUIRED_RESULT QString errorTemplate(const QString &reason, const QString &templateName, const Grantlee::Template &errorTemplate);
+    [[nodiscard]] KTextTemplate::Context createContext(const QVariantHash &data = QVariantHash(), const QByteArray &applicationDomain = QByteArray());
+    [[nodiscard]] QString errorTemplate(const QString &reason, const QString &templateName, const KTextTemplate::Template &errorTemplate);
 
     QStringList displayExtraVariables;
     QString themeFileName;
@@ -36,12 +34,8 @@ public:
     QStringList absolutePaths;
     QString author;
     QString email;
-
-    QSharedPointer<Grantlee::FileSystemTemplateLoader> loader;
-
+    QSharedPointer<KTextTemplate::FileSystemTemplateLoader> loader;
     static QSharedPointer<GrantleeKi18nLocalizer> sLocalizer;
-    static Grantlee::Engine *sEngine;
+    static KTextTemplate::Engine *sEngine;
 };
 }
-
-#endif
